.. _roadmap-label:

==========================
Proposed Roadmap
==========================

0.1
   First release
0.1.5 (Mid December 2018)
   Have good test coverage
0.2 (Mid January 2019)
   Make template tags so that customising and using in own templates is easier
   Internationalise urls
0.3 (End February 2019)
   Multiple Galleries per site
0.4 (April 2019)
   Permissions controls
   Subcategories